@@ -34,6 +34,8 @@ train.default <- function(x, y,
       classLevels <- levels(y)
       if(length(classLevels) > 2 & (method %in% c("gbm", "glmboost", "ada", "gamboost", "blackboost", "penalized", "glm", "earth")))
         stop("This model is only implemented for two class problems")
+      if(length(classLevels) < 3 & (method %in% c("vbmpRadial")))
+        stop("This model is only implemented for 3+ class problems")      
       if(metric %in% c("RMSE", "Rsquared")) 
         stop(paste("Metric", metric, "not applicable for classification models"))
     } else {
